@@ -6,4 +6,4 @@
 from .logger import Priority
 from .logger import Error
 from .logger import Warning
-from .logger import Logger
\ No newline at end of file
+from .logger import log
\ No newline at end of file
